asr.core.material
=================

.. automodule:: asr.core.material

   
   
   .. rubric:: Functions

   
   .. autofunction:: get_material_from_folder
   .. autofunction:: get_webpanels_from_material
   .. autofunction:: make_panel_figures
   
   

   
   
   .. rubric:: Classes

   
   .. autoclass:: Material
   
   

   
   
   